summaryrefslogtreecommitdiffstats
path: root/klinkstatus/src/utils/xsl.h
diff options
context:
space:
mode:
Diffstat (limited to 'klinkstatus/src/utils/xsl.h')
-rw-r--r--klinkstatus/src/utils/xsl.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/klinkstatus/src/utils/xsl.h b/klinkstatus/src/utils/xsl.h
index 9d12c1c1..7fb6af70 100644
--- a/klinkstatus/src/utils/xsl.h
+++ b/klinkstatus/src/utils/xsl.h
@@ -20,7 +20,7 @@
#ifndef XSL_H
#define XSL_H
-#include <qobject.h>
+#include <tqobject.h>
class XSLTPrivate;
@@ -56,7 +56,7 @@ public:
*
* Constructs a new XSLT parser using the provided XSLT document
*/
- XSLT( const QString &xsltDocument, QObject *parent = 0L );
+ XSLT( const TQString &xsltDocument, TQObject *parent = 0L );
virtual ~XSLT();
@@ -65,7 +65,7 @@ public:
*
* @return an ORed set of @ref Flags, or 0 if none
*/
- void setXSLT( const QString &document );
+ void setXSLT( const TQString &document );
/**
* Transforms the XML string using the XSLT document, synchronously
@@ -73,17 +73,17 @@ public:
* @param xmlString The source XML
* @return The result of the transformation
*/
- QString transform( const QString &xmlString );
+ TQString transform( const TQString &xmlString );
/**
* Transforms the XML string using the XSLT document, asynchronously
*
* @param xmlString The source XML
* @param target The QObject that contains the slot to be executed when processing is complete
* @param slotCompleted A slot that accepts a QVariant & paramater, that is the result
* of the transformation
*/
- void transformAsync( const QString &xmlString, QObject *target, const char *slotCompleted );
+ void transformAsync( const TQString &xmlString, TQObject *target, const char *slotCompleted );
/**
* Check whether the XSLT document is valid
@@ -73,17 +73,17 @@ public:
*
* @param xmlString The source XML
- * @param target The QObject that contains the slot to be executed when processing is complete
- * @param slotCompleted A slot that accepts a QVariant & paramater, that is the result
+ * @param target The TQObject that contains the slot to be executed when processing is complete
+ * @param slotCompleted A slot that accepts a TQVariant & paramater, that is the result
* of the transformation
*/